/******************************************************************************

  driver.c

  The list of all available drivers. Drivers have to be included here to be
  recognized by the executable.

  To save some typing, we use a hack here. This file is recursively #included
  twice, with different definitions of the DRIVER() macro. The first one
  declares external references to the drivers; the second one builds an array
  storing all the drivers.

******************************************************************************/

#include "driver.h"


#ifndef DRIVER_RECURSIVE

/* The "root" driver, defined so we can have &driver_##NAME in macros. */
struct GameDriver driver_0 =
{
	__FILE__,
	0,
	"",
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	NOT_A_DRIVER
};

#endif

#ifdef TINY_COMPILE
extern struct GameDriver TINY_NAME;

const struct GameDriver *drivers[] =
{
	&TINY_NAME,
	0	/* end of array */
};

#else

#ifndef DRIVER_RECURSIVE

#define DRIVER_RECURSIVE

/* step 1: declare all external references */
#define DRIVER(NAME) extern struct GameDriver driver_##NAME;
#define TESTDRIVER(NAME) extern struct GameDriver driver_##NAME;
#include "driver.c"

/* step 2: define the drivers[] array */
#undef DRIVER
#undef TESTDRIVER
#define DRIVER(NAME) &driver_##NAME,
#define TESTDRIVER(NAME)
const struct GameDriver *drivers[] =
{
#include "driver.c"
	0	/* end of array */
};

#else	/* DRIVER_RECURSIVE */


	/* misfit games */
        DRIVER( diggermn )	/* 0066 (c) 1994 Face ? */
	DRIVER( monaco )	/* (c) 1979 SEGA*/
	DRIVER( pong )
	DRIVER( goldstar )	/* IGS */
	DRIVER( goldstbl )	/* IGS */
	DRIVER( csk227it )	/* (c) [1993] IGS */
	DRIVER( csk234it )	/* (c) [1993] IGS */
	DRIVER( lottofun )	/* (c) 1987 H.A.R. Management */
	DRIVER( pontoon )	/* 6011 - (c) 1985 Tehkan */     
    	DRIVER( galagax )      /* Jerky - Chris Moore hack of 1942 */
	DRIVER( killiped )     /* The Dog hack of Centipede */
  	DRIVER( cemescry )     /* NoSync hack of Centipede */
 	DRIVER( vectrped )     /* T-Bone hack of Centipede */
	DRIVER( vectiped )     /* The Dog hack of Centipede */
	DRIVER( trukker )      /* Grimlick hack of Frogger */
	DRIVER( galgaxin )     /* T-Bone hack of Galaga */
	DRIVER( galaga99 )     /* Jerky and Sil hack of Galaga */
    	DRIVER( galaped )      /* Cary Barnhard hack of Galaga */
	DRIVER( galinvad )     /* T-Bone hack of Galaxian */
	DRIVER( vectrgal )     /* T-Bone hack of Galaxian */
	DRIVER( buglaxn )      /* The Dog hack of Galaxian */
 	DRIVER( gaylaxn )      /* The Dog hack of Galaxian Part X */
	DRIVER( galaxkyo )     /* unknown hack of Galaxian Part X */
	DRIVER( jrvectr )      /* T-Bone hack of Jr. Pac-Man */
	DRIVER( housepty )     /* Jerky hack of Mappy */
    	DRIVER( crackhea )     /* Cary Barnhard hack of Mappy */
	DRIVER( handiman )     /* Bobby Tribble hack of Tron */
	DRIVER( silliped )     /* Andy hack of Millipede */
	DRIVER( newdigdo )     /* Vic 20 George and Jerky hack of... */
	DRIVER( mrdigdo )      /* Justin Clark hack of Mr. Do! */
	DRIVER( rxtron )       /* Jerky and Sil hack of Rally-X */
	DRIVER( pengman )      /* Jerry Lawrence hack of Pac-Man (Midway) */
	DRIVER( pacman3d )     /* Sil hack of Pac-Man (Midway) */
	DRIVER( namcosil )     /* Sil hack of Pac-Man (Namco) */
	DRIVER( pacpopey )     /* unknown hack of Pac-Man (Namco) */
	DRIVER( mspacat2 )     /* Sil hack of Miss Pac Plus */
	DRIVER( pac2600 )      /* Bobby Tribble hack of Pac-Man (Midway) */
	DRIVER( pacmini )      /* Bobby Tribble hack of Pac-Man (Midway) */
 	DRIVER( pacmini2 )     /* Bobby Tribble hack of Pac-Man (Midway) */
	DRIVER( pmad )         /* SirScotty and Sil hack of Pac-Man (Midway) */
    	DRIVER( pmad_a )       /* SirScotty, Sil, Jerry hack of Pac-Man (Midway) */
	DRIVER( europac )      /* Stefano 'Jojo' Priore hack of Pac-Man (Midway) */
	DRIVER( eltonpac )     /* Sil hack of Pac-Man (Midway) */
 	DRIVER( brakman )      /* Jerry Lawrence hack of Pac-Man (Midway) */
     	DRIVER( vectrpac )     /* T-Bone hack of Pac-Man (Midway) */
	DRIVER( roboman )      /* Rungedog hack of Pac-Man (Midway) */
	DRIVER( newpuck2 )     /* Scotty hack of Pac-Man */
	DRIVER( mazeman )      /* Sil hack of Pac-Man */
	DRIVER( msdstorm )     /* Mike Naylor hack of Ms. Pac-Man */
	DRIVER( mselton )      /* Sil hack of Ms. Pac-Man */
     	DRIVER( msvectr )      /* T-Bone hack of Ms. Pac-Man */
	DRIVER( msf1pac )         /* Sil hack of Ms. Pac-Man */
	DRIVER( msindy )       /* Sil hack of Ms. Pac-Man */
	DRIVER( mspacrip )     /* R3mer hack of Ms. Pac-Man */
  	DRIVER( msyakman )     /* Jeff 'YaK' Minter hack of Ms. Pac-Man */
	DRIVER( msberzk )      /* Bobby Tribble hack of Ms. Pac-Man */
	DRIVER( vectratk )     /* Sil and T-Bone hack of Ms. Pac-Man */
	DRIVER( heartbrn )     /* unknown hack of Ms. Pac-Man */
	DRIVER( ms2600 )       /* T-Bone hack of Ms. Pac-Man */
     	DRIVER( mspacnes )     /* T-Bone hack of Ms. Pac-Man */
	DRIVER( mspacren )     /* T-Bone hack of Ms. Pac-Man */
	DRIVER( mspac6m )      /* Sil hack of Ms. Pac-Man */
     	DRIVER( puckren )      /* Peter Storey hack of Puck-Man */
	DRIVER( vecbtime )	    /* T-Bone hack of Burgertime */
	DRIVER( vectrsup )     /* T-Bone hack of Super Pac-Man */
	DRIVER( vecpengo )     /* T-Bone hack of Pengo */
 	DRIVER( xensrev )      /* Jeff Morris hack of Pac-Man */
      	DRIVER( mspacad )      /* Sil hack of Ms. Pac-Man */
	DRIVER( kong2600 )     /* Vic Twenty George hack of Donkey Kong */
	DRIVER( pacipede )     /* Jeff Coleburn hack of Centiped */
	DRIVER( phoenixr )     /* CYBERYOGI =CO= Windler hack of Phoenix */
        DRIVER( superdog )     /* Jerky Hack Hack of scramble */
        DRIVER( offender )     /* Chris Henry hack of scramble */        
        DRIVER( multi14 )      /* Multi-Pac 1.4 by Clay Cowgill (c) 1998 */
        DRIVER( multi15 )      /* Multi-Pac 1.5 by Clay Cowgill (c) 1998 */
        DRIVER( superabc )     /* SuperABC Pacman by Two-Bit Score (c) 1999 */
        DRIVER( kingdmgp )     /* Neill Corlett's  English Text Hack */

#endif	/* DRIVER_RECURSIVE */

#endif	/* TINY_COMPILE */
